aboutsummaryrefslogtreecommitdiffstats
path: root/components/util/range.rs
diff options
context:
space:
mode:
authorSimon Sapin <simon.sapin@exyr.org>2015-01-31 14:36:05 +0100
committerMatt Brubeck <mbrubeck@limpet.net>2015-02-11 14:48:34 -0800
commitd5dd1d658e5d79701fb9d028479a0fcb26a033fa (patch)
tree0c243afe9d7d82695d16bd43d72e88600e4414ef /components/util/range.rs
parentbc6882bdefc318402a46ede1494eb79339705c21 (diff)
downloadservo-d5dd1d658e5d79701fb9d028479a0fcb26a033fa.tar.gz
servo-d5dd1d658e5d79701fb9d028479a0fcb26a033fa.zip
Upgrade to rustc ba2f13ef0 2015-02-04
Diffstat (limited to 'components/util/range.rs')
-rw-r--r--components/util/range.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/components/util/range.rs b/components/util/range.rs
index 8c217beb218..dba80b458f2 100644
--- a/components/util/range.rs
+++ b/components/util/range.rs
@@ -9,7 +9,7 @@ use std::num;
use std::num::Int;
/// An index type to be used by a `Range`
-pub trait RangeIndex: Int + fmt::Show {
+pub trait RangeIndex: Int + fmt::Debug {
type Index;
fn new(x: Self::Index) -> Self;
fn get(self) -> Self::Index;
@@ -28,7 +28,7 @@ impl RangeIndex for int {
#[macro_export]
macro_rules! int_range_index {
($(#[$attr:meta])* struct $Self:ident($T:ty)) => (
#[derive(Clone, PartialEq, PartialOrd, Eq, Ord, Show, Copy)]
$(#[$attr])*
pub struct $Self(pub $T);
@@ -194,7 +194,7 @@ pub struct Range<I> {
length: I,
}
-impl<I: RangeIndex> fmt::Show for Range<I> {
+impl<I: RangeIndex> fmt::Debug for Range<I> {
fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
write!(f, "[{:?} .. {:?})", self.begin(), self.end())
}
@@ -28,7 +28,7 @@ impl RangeIndex for int {
macro_rules! int_range_index {
($(#[$attr:meta])* struct $Self:ident($T:ty)) => (
- #[derive(Clone, PartialEq, PartialOrd, Eq, Ord, Show, Copy)]
+ #[derive(Clone, PartialEq, PartialOrd, Eq, Ord, Debug, Copy)]
$(#[$attr])*
pub struct $Self(pub $T);